% This script contains an example of running the APPLE picking package

% Micrographs from the beta-galactosidase dataset we use in this example are publicly available
% from EMPIAR (the Electron Microscopy Public Image Archive)
% (Iudin, A., Korir, P., Salavert-Torres, J., Kleywegt, G., & Patwardhan,
% A. (2016). EMPIAR: A public archive for raw electron microscopy image data.
% Nature Methods, 13.) as EMPIAR-10017
% (Scheres, S. H. (2015). Semi-automated selection of cryo-EM
% particles in RELION-1.3. Journal of Structural Biology,
% 189, 114-122.)
% Micrographs from the KLH dataset we use in this example are publically
% available as well (Zhu, Y., Carragher, B., Mouche, F., & Potter, C. S. (2003).
% Automatic particle detection through efficient hough transforms.
% IEEE Transactions on Medical Imaging, 22, 1053-1062.)

% The command for particle picking is
% ApplePicker( fileName or directory, particleSize, ** optional parameters ** );

% Set the following to true if you wish to process all micrographs in the
% dataset.
runAll = false;

% Set the following to true if you wish to see images of the particle picking
% for each micrograph.
showImages = false;

% Download beta-galactosidase dataset.
if ~exist(fullfile(pkgRoot(), 'data', 'empiar10017'), 'dir')
    downloadEmpiar10017();
end

if runAll
    % Run all micrographs in data/empiar10017.
    ApplePicker(fullfile(pkgRoot(), 'data', 'empiar10017'), 78, ...
        'nOverlap', 20, ...
        'qSize', 52, ...
        'classifierProps', [600; 10000], ...
        'containerSize', 450, ...
        'minParticle', 20, ...
        'maxParticle', 80, ...
        'showImages', showImages);
else
    % Run a single micrograph in data/empiar10017.
    mName = 'Falcon_2012_06_12-14_57_34_0.mrc';
    ApplePicker(fullfile(pkgRoot(), 'data', 'empiar10017', mName), 78, ...
        'nOverlap', 20, ...
        'qSize', 52, ...
        'classifierProps', [600; 10000], ...
        'containerSize', 450, ...
        'minParticle', 20, ...
        'maxParticle', 80, ...
        'showImages', showImages);
end

% Download KLH dataset.
if ~exist(fullfile(pkgRoot(), 'data', 'klh'), 'dir')
    downloadKlh();
end

if runAll
    % Run all micrographs in data/klh.
    ApplePicker(fullfile(pkgRoot(), 'data', 'klh'), 160, ...
        'nOverlap', 110, ...
        'qSize', 60, ...
        'classifierProps', [800; 2500], ...
        'containerSize', 450, ...
        'minParticle', 60, ...
        'maxParticle', 220, ...
        'showImages', showImages);

else
    % Run a single micrograph data/klh.
    mName = '01nov26b.006.005.002.002.mrc';
    ApplePicker(fullfile(pkgRoot(), 'data', 'klh', mName), 160, ...
        'nOverlap', 110, ...
        'qSize', 60, ...
        'classifierProps', [800; 2500], ...
        'containerSize', 450, ...
        'minParticle', 60, ...
        'maxParticle', 220, ...
        'showImages', showImages);
end
